Rocco Rutte:
[apps/madmutt.git] / init.h
diff --git a/init.h b/init.h
index 4ff0020..d1250cd 100644 (file)
--- a/init.h
+++ b/init.h
@@ -542,7 +542,7 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
    ** \fBNote:\fP you should not enable this unless you are using Sendmail
-   ** 8.8.x or greater.
+   ** 8.8.x or greater or in connection with the SMTP support via libESMTP.
    ** .pp
    ** This variable sets the request for when notification is returned.  The
    ** string consists of a comma separated list (no spaces!) of one or more
@@ -557,7 +557,7 @@ struct option_t MuttVars[] = {
   /*
    ** .pp
    ** \fBNote:\fP you should not enable this unless you are using Sendmail
-   ** 8.8.x or greater.
+   ** 8.8.x or greater or in connection with the SMTP support via libESMTP.
    ** .pp
    ** This variable controls how much of your message is returned in DSN
    ** messages.  It may be set to either \fIhdrs\fP to return just the
@@ -1235,7 +1235,15 @@ struct option_t MuttVars[] = {
    ** from (instead to the author only). Setting this option to ``\fIask-yes\fP'' or
    ** ``\fIask-no\fP'' will ask if you really intended to reply to the author only.
    */
-  {"max_line_length", DT_NUM, R_NONE, UL &MaxLineLength, 0},
+  {"max_display_recips", DT_NUM, R_PAGER, UL &MaxDispRecips, 0},
+  /*
+   ** .pp
+   ** When set non-zero, this specifies the maximum number of recipient header
+   ** lines (\fTTo:\fP, \fTCc:\fP and \fTBcc:\fP) to display in the pager if header
+   ** weeding is turned on. In case the number of lines exeeds its value, the
+   ** last line will have 3 dots appended.
+   */
+  {"max_line_length", DT_NUM, R_PAGER, UL &MaxLineLength, 0},
   /*
    ** .pp
    ** When \fIset\fP, the maximum line length for displaying ``format = flowed'' messages is limited
@@ -2343,7 +2351,8 @@ struct option_t MuttVars[] = {
    ** (S/MIME only)
    */
 #if defined(USE_LIBESMTP)
-  {"smtp_auth_username", DT_STR, R_NONE, UL &SmtpAuthUser, 0},
+  {"smtp_auth_username", DT_SYN, R_NONE, UL "smtp_user", 0},
+  {"smtp_user", DT_STR, R_NONE, UL &SmtpAuthUser, 0},
   /*
    ** .pp
    ** Availability: SMTP
@@ -2352,13 +2361,14 @@ struct option_t MuttVars[] = {
    ** Defines the username to use with SMTP AUTH.  Setting this variable will
    ** cause Mutt-ng to attempt to use SMTP AUTH when sending.
    */
-  {"smtp_auth_password", DT_STR, R_NONE, UL &SmtpAuthPass, 0},
+  {"smtp_auth_password", DT_SYN, R_NONE, UL "smtp_pass", 0},
+  {"smtp_pass", DT_STR, R_NONE, UL &SmtpAuthPass, 0},
   /*
    ** .pp
    ** Availability: SMTP
    **
    ** .pp
** Defines the password to use with SMTP AUTH.  If ``$$smtp_auth_username''
    ** is set, but this variable is not, you will be prompted for a password
    ** when sending.
    ** .pp
@@ -2366,6 +2376,20 @@ struct option_t MuttVars[] = {
    ** presents a security risk since the superuser of your machine may read it
    ** regardless of the file's permissions.  
    */
+  {"smtp_envelope", DT_STR, R_NONE, UL &SmtpEnvFrom, 0},
+  /*
+   ** .pp
+   ** Availability: SMTP
+   **
+   ** .pp
+   ** If this variable is non-empty, it'll be used as the envelope sender. If it's empty
+   ** (the default), the value of the regular \fTFrom:\fP header will be used.
+   **
+   ** .pp
+   ** This may be necessary as some providers don't allow for arbitrary values
+   ** as the envelope sender but only a particular one which may not be the same as the
+   ** user's desired \fTFrom:\fP header.
+   */
   {"smtp_host", DT_STR, R_NONE, UL &SmtpHost, 0},
   /*
    ** .pp
@@ -2388,6 +2412,20 @@ struct option_t MuttVars[] = {
    ** Defaults to 25, the standard SMTP port, but RFC 2476-compliant SMTP
    ** servers will probably desire 587, the mail submission port.
    */
+  {"smtp_use_tls", DT_STR, R_NONE, UL &SmtpUseTLS, 0},
+  /*
+   ** .pp
+   ** Availability: SMTP (and SSL)
+   **
+   ** .pp
+   ** Defines wether to use STARTTLS. If this option is set to ``\fIrequired\fP''
+   ** and the server does not support STARTTLS or there is an error in the
+   ** TLS Handshake, the connection will fail. Setting this to ``\fIenabled\fP''
+   ** will try to start TLS and continue without TLS in case of an error.
+   **
+   **.pp
+   ** Muttng still needs to have SSL support enabled in order to use it.
+   */
 #endif
 #if defined(USE_SSL) || defined(USE_GNUTLS)
 #ifdef USE_SSL
@@ -3086,16 +3124,7 @@ struct option_t MuttVars[] = {
    ** assumed that filename is a shell command and input should be read from
    ** its stdout.
    */
-  {"signoff_string", DT_STR, R_NONE, UL &SignOffString, UL 0},
-  /*
-   ** .pp
-   ** If \fIset\fP, this string will be inserted before the signature. This is useful
-   ** for people that want to sign off every message they send with their name.
-   ** .pp
-   ** If you want to insert your website's URL, additional contact information or 
-   ** witty quotes into your mails, better use a signature file instead of
-   ** the signoff string.
-   */
+  {"signoff_string", DT_SYN, R_NONE, UL "post_indent_string", 0},
   {"simple_search", DT_STR, R_NONE, UL &SimpleSearch, UL "~f %s | ~s %s"},
   /*
    ** .pp
@@ -3484,10 +3513,12 @@ struct option_t MuttVars[] = {
    ** .pp
    ** \fBWarning:\fP do not set this variable unless you are using a version
    ** of sendmail which supports the \fT-B8BITMIME\fP flag (such as sendmail
-   ** 8.8.x) or you may not be able to send mail.
+   ** 8.8.x) or in connection with the SMTP support via libESMTP.
+   ** Otherwise you may not be able to send mail.
    ** .pp
-   ** When \fIset\fP, Mutt-ng will invoke ``$$sendmail'' with the \fT-B8BITMIME\fP
-   ** flag when sending 8-bit messages to enable ESMTP negotiation.
+   ** When \fIset\fP, Mutt-ng will either invoke ``$$sendmail'' with the \fT-B8BITMIME\fP
+   ** flag when sending 8-bit messages to enable ESMTP negotiation or tell
+   ** libESMTP to do so.
    */
   {"use_domain", DT_BOOL, R_NONE, OPTUSEDOMAIN, 1},
   /*
@@ -2352,13 +2361,14 @@ struct option_t MuttVars[] = {
    **
    ** .pp
-   ** Defines the password to use with SMTP AUTH.  If ``$$smtp_auth_username''
+   ** Defines the password to use with SMTP AUTH.  If ``$$smtp_user''
    ** is set, but this variable is not, you will be prompted for a password
    ** when sending.